bbolt.bucket


bucketclj

(bucket parent name)

Returns a bucket from a Tx or Bucket.

Returns a bucket from a Tx or Bucket.
raw docstring

bucket-deleteclj

(bucket-delete b key)

bucket-getclj

(bucket-get b key)

bucket-putclj

(bucket-put b key val)

collect-page-idsclj

(collect-page-ids b)

create-bucketclj

(create-bucket parent name)

Creates a bucket under a Tx or Bucket.

Creates a bucket under a Tx or Bucket.
raw docstring

create-bucket-if-not-existsclj

(create-bucket-if-not-exists parent name)

delete-bucketclj

(delete-bucket parent name)

foreachclj

(foreach parent f)

Iterate over buckets in a Tx or key/value pairs in a Bucket.

Iterate over buckets in a Tx or key/value pairs in a Bucket.
raw docstring

foreach-bucketclj

(foreach-bucket parent f)

Iterate over buckets in a Tx or Bucket, ignoring key/value entries.

Iterate over buckets in a Tx or Bucket, ignoring key/value entries.
raw docstring

load-bucketclj

(load-bucket tx root-pgid sequence inline-bytes)

move-bucketclj

(move-bucket parent old-name new-name)

Rename a bucket within a Tx or Bucket, or move a bucket to another parent bucket.

Rename a bucket within a Tx or Bucket, or move a bucket to another parent bucket.
raw docstring

new-bucketclj

(new-bucket tx)

next-sequenceclj

(next-sequence b)

rebalance-bucket-recursiveclj

(rebalance-bucket-recursive b)

sequenceclj

(sequence b)

set-fill-percent!clj

(set-fill-percent! b v)

set-sequence!clj

(set-sequence! b v)

spill-bucket-recursiveclj

(spill-bucket-recursive b)

spill-bucket-rootclj

(spill-bucket-root b)

cljdoc builds & hosts documentation for Clojure/Script libraries