bbolt.main


bucketclj

(bucket parent name)

checkclj

(check tx)
(check tx opts)

Return a seq of consistency check errors for a transaction.

Return a seq of consistency check errors for a transaction.
raw docstring

close-dbclj

(close-db db)

compactclj

(compact dst-db src-db tx-max-size)

Copy keys from src-db into dst-db with optional tx-max-size caps. Mirrors Go's bolt.Compact behavior.

Copy keys from src-db into dst-db with optional tx-max-size caps.
Mirrors Go's bolt.Compact behavior.
raw docstring

create-bucketclj

(create-bucket parent name)

create-bucket-if-not-existsclj

(create-bucket-if-not-exists parent name)

cursorclj

(cursor parent)

deleteclj

(delete b key)

delete-bucketclj

(delete-bucket parent name)

entriesclj

(entries c)

firstclj

(first c)

first-rawclj

(first-raw c)

foreachclj

(foreach parent f)

foreach-bucketclj

(foreach-bucket parent f)

getclj

(get b key)

inspectclj

(inspect parent)

keysclj

(keys c)

lastclj

(last c)

move-bucketclj

(move-bucket parent old-name new-name)

nextclj

(next c)

next-rawclj

(next-raw c)

next-sequenceclj

(next-sequence b)

open-dbclj

(open-db path)
(open-db path opts)

page-infoclj

(page-info tx pgid)

Return page info for a pgid. Uses freelist membership to mark pages as free.

Return page info for a pgid. Uses freelist membership to mark pages as free.
raw docstring

prevclj

(prev c)

putclj

(put b key val)

seekclj

(seek c key)

seek-rawclj

(seek-raw c key)

sequenceclj

(sequence b)

set-fill-percentclj

(set-fill-percent b v)

set-sequenceclj

(set-sequence b v)

statsclj

(stats parent)

updateclj

(update db f)
(update db f opts)

valuesclj

(values c)

viewclj

(view db f)

with-tx-rocljmacro

(with-tx-ro [sym db] & body)

with-tx-rwcljmacro

(with-tx-rw [sym db] & body)

cljdoc builds & hosts documentation for Clojure/Script libraries