bbolt.tx


begin-txclj

(begin-tx db writable?)

checkclj

(check tx)
(check tx {:keys [page-id kv-stringer] :or {page-id 0}})

Run consistency checks for a transaction. Returns a seq of error strings.

Run consistency checks for a transaction. Returns a seq of error strings.
raw docstring

commitclj

(commit tx)
(commit tx {:keys [skip-sync?]})

page-infoclj

(page-info tx pgid)

Return page info for a pgid, with type set to "free" when the pgid is in the freelist. Returns nil when pgid is beyond the high-water mark.

Return page info for a pgid, with type set to "free" when the pgid is in the freelist.
Returns nil when pgid is beyond the high-water mark.
raw docstring

rollbackclj

(rollback tx)

tx-allocate-pageclj

(tx-allocate-page tx)

updateclj

(update db f)
(update db f commit-opts)

viewclj

(view db f)

cljdoc builds & hosts documentation for Clojure/Script libraries