miladb.blob


get-blobclj

(get-blob bucket hash-bytes)

Fetch blob bytes by hash.

Fetch blob bytes by hash.
raw docstring

hash-bytesclj

(hash-bytes data)

Return the xxh3 hash as an 8-byte array.

Return the xxh3 hash as an 8-byte array.
raw docstring

put-blob!clj

(put-blob! bucket data)

Store bytes in the blob bucket, return hash bytes.

Store bytes in the blob bucket, return hash bytes.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries