miladb.db


close-dbclj

(close-db mdb)

create-dbclj

(create-db path)
(create-db path opts)

create-target-stateclj

(create-target-state path)
(create-target-state path opts)

Returns :blank|:initialized or throws when the file has a partial or invalid MilaDB initialization.

Returns :blank|:initialized or throws when the file has a partial or invalid
MilaDB initialization.
raw docstring

db?clj

(db? v)

open-dbclj

(open-db path)
(open-db path opts)

store?clj

(store? v)

viewclj

(view mdb f)

with-write-txclj

(with-write-tx mdb f)
(with-write-tx mdb f opts)

cljdoc builds & hosts documentation for Clojure/Script libraries