miladb.entity


entityclj

(entity view eid)

Create a lazy entity view for eid.

Create a lazy entity view for eid.
raw docstring

entity-dbclj

(entity-db ent)

entity?clj

(entity? v)

touchclj

(touch ent)

Realize all attributes for an entity, including component entities recursively.

Realize all attributes for an entity, including component entities recursively.
raw docstring

touch->mapclj

(touch->map ent)

Touch and return a realized entity map.

Touch and return a realized entity map.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries