miladb.keys


aevt-indexclj


aevt-keyclj

(aevt-key a-id e-bytes tx-id added? v)

Build AEVT key bytes: (2, a, e, t*, retract?, v). retract? is (not added?) so additions sort before retractions for the same t*.

Build AEVT key bytes: (2, a, e, t*, retract?, v).
retract? is (not added?) so additions sort before retractions for the same t*.
raw docstring

aevt-prefixclj

(aevt-prefix a-id e-bytes)

Prefix bytes for (2, a, e).

Prefix bytes for (2, a, e).
raw docstring

avet-indexclj


avet-keyclj

(avet-key a-id v e-bytes tx-id)

Build AVET key bytes: (3, a, v, e, t*).

Build AVET key bytes: (3, a, v, e, t*).
raw docstring

avet-prefixclj

(avet-prefix a-id v)

Prefix bytes for (3, a, v).

Prefix bytes for (3, a, v).
raw docstring

eavt-indexclj


eavt-keyclj

(eavt-key e-bytes a-id tx-id added? v)

Build EAVT key bytes: (1, e, a, t*, retract?, v). retract? is (not added?) so additions sort before retractions for the same t*.

Build EAVT key bytes: (1, e, a, t*, retract?, v).
retract? is (not added?) so additions sort before retractions for the same t*.
raw docstring

eavt-prefixclj

(eavt-prefix e-bytes a-id)

Prefix bytes for (1, e, a).

Prefix bytes for (1, e, a).
raw docstring

log-indexclj


log-keyclj

(log-key tx-id e-bytes a-id v added?)

Build LOG key bytes: (0, t*, e, a, v, added?).

Build LOG key bytes: (0, t*, e, a, v, added?).
raw docstring

pack-prefixclj

(pack-prefix prefix)

Pack a tuple or return bytes for an already-packed prefix.

Pack a tuple or return bytes for an already-packed prefix.
raw docstring

prefix->rangeclj

(prefix->range prefix)

Return [start end-exclusive] bytes for a prefix tuple or byte-array.

Return [start end-exclusive] bytes for a prefix tuple or byte-array.
raw docstring

prefix-endclj

(prefix-end prefix)

Return the exclusive upper bound for a byte prefix, or nil if unbounded.

Return the exclusive upper bound for a byte prefix, or nil if unbounded.
raw docstring

t-ascclj

(t-asc t-desc)

Decode descending tx-id back to ascending tx-id.

Decode descending tx-id back to ascending tx-id.
raw docstring

t-descclj

(t-desc tx-id)

Encode tx-id in descending order (newer txs sort first).

Encode tx-id in descending order (newer txs sort first).
raw docstring

vaet-indexclj


vaet-keyclj

(vaet-key v a-id e-bytes tx-id)

Build VAET key bytes: (4, v, a, e, t*).

Build VAET key bytes: (4, v, a, e, t*).
raw docstring

vaet-prefixclj

(vaet-prefix v a-id)

Prefix bytes for (4, v, a).

Prefix bytes for (4, v, a).
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries