Clojure only.

miladb.query


qclj

(q query & args)

Execute a basic Datalog query. Returns realized results by default.

Execute a basic Datalog query. Returns realized results by default.
raw docstring

query-statsclj

(query-stats query & args)

Execute a query and return results with operator stats from the execution plan.

Execute a query and return results with operator stats from the execution plan.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries