miladb.schema-data


base-schema-stateclj

(base-schema-state db)

Inspect the MilaDB schema bootstrap state for db.

Returns a map with :status equal to one of:

  • :missing
  • :ok
  • :unsupported-version
  • :incomplete
Inspect the MilaDB schema bootstrap state for `db`.

Returns a map with `:status` equal to one of:
- `:missing`
- `:ok`
- `:unsupported-version`
- `:incomplete`
raw docstring

bootstrap-catalogclj


bootstrap-max-aidclj


ensure-base-schema!clj

(ensure-base-schema! db)

Ensure schema-as-data bootstrap is present.

This writes the bootstrapped schema datoms at tx-id 0 and then records a format/version marker in the meta bucket, in the same write transaction.

Safe to call repeatedly for databases created with this format version.

Ensure schema-as-data bootstrap is present.

This writes the bootstrapped schema datoms at tx-id 0 and then records a
format/version marker in the meta bucket, in the same write transaction.

Safe to call repeatedly for databases created with this format version.
raw docstring

load-catalogclj

(load-catalog db)
(load-catalog db {:keys [as-of overlay-datoms]})

Build a catalog cache from schema datoms.

Options:

  • :as-of (tx-id) Build schema as-of tx-id.
  • :overlay-datoms Optional overlay datoms (e.g. from with).
Build a catalog cache from schema datoms.

Options:
- :as-of (tx-id)         Build schema as-of tx-id.
- :overlay-datoms        Optional overlay datoms (e.g. from `with`).
raw docstring

require-base-schema!clj

(require-base-schema! db)

Validate that the MilaDB schema bootstrap is present.

Throws when the database has not been initialized via create-database or is missing required builtin schema datoms.

Validate that the MilaDB schema bootstrap is present.

Throws when the database has not been initialized via `create-database` or is
missing required builtin schema datoms.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries