miladb.tuple


bytes->hexclj

(bytes->hex val)

Return a lowercase hex string for a byte array.

Return a lowercase hex string for a byte array.
raw docstring

compare-itemsclj

(compare-items a b)

Compare two tuple items using tuple ordering rules.

Compare two tuple items using tuple ordering rules.
raw docstring

compare-tuplesclj

(compare-tuples a b)

Compare two tuples for ordering consistent with packed byte order.

Compare two tuples for ordering consistent with packed byte order.
raw docstring

from-itemsclj

(from-items items)

Create a Tuple from a sequence of items.

Create a Tuple from a sequence of items.
raw docstring

packclj

(pack t)
(pack t prefix)

Pack a Tuple or list of items into a byte array.

Pack a Tuple or list of items into a byte array.
raw docstring

pack-hexclj

(pack-hex t)

Pack a tuple and render the bytes as a lowercase hex string.

Pack a tuple and render the bytes as a lowercase hex string.
raw docstring

pack-maybe-versionstampclj

(pack-maybe-versionstamp t)

Pack a Tuple, using versionstamp format if needed (internal helper).

Pack a Tuple, using versionstamp format if needed (internal helper).
raw docstring

pack-with-versionstampclj

(pack-with-versionstamp t)
(pack-with-versionstamp t prefix)

Pack a Tuple with exactly one incomplete Versionstamp, appending the version offset.

Pack a Tuple with exactly one incomplete Versionstamp, appending the version offset.
raw docstring

tupleclj

(tuple & items)

Create a Tuple from items.

Create a Tuple from items.
raw docstring

tuple-itemsclj

(tuple-items t)

Return a copy of Tuple elements.

Return a copy of Tuple elements.
raw docstring

tuple-packed-sizeclj

(tuple-packed-size t)
(tuple-packed-size t nested?)

Return the packed size of a Tuple.

Return the packed size of a Tuple.
raw docstring

tuple?clj

(tuple? v)

unpackclj

(unpack bytes)
(unpack bytes offset length)

Decode a byte array into a Tuple.

Decode a byte array into a Tuple.
raw docstring

unpack-itemsclj

(unpack-items src)
(unpack-items src offset length)

Decode tuple items from a byte array or other bytes-like input.

Decode tuple items from a byte array or other bytes-like input.
raw docstring

versionstamp-completeclj

(versionstamp-complete tr-version)
(versionstamp-complete tr-version user-version)

versionstamp-complete?clj

(versionstamp-complete? v)

versionstamp-from-bytesclj

(versionstamp-from-bytes version-bytes)

versionstamp-incompleteclj

(versionstamp-incomplete)
(versionstamp-incomplete user-version)

versionstamp-user-versionclj

(versionstamp-user-version v)

versionstamp?clj

(versionstamp? v)

cljdoc builds & hosts documentation for Clojure/Script libraries