XXH3 64-bit hash
ported from hash4j source (com.dynatrace.hash4j)
XXH3 64-bit hash ported from hash4j source (com.dynatrace.hash4j)
(hash64 input)(hash64 input seed)(hash64 input off length seed)Return XXH3 64-bit hash of a byte array with optional seed and range.
Return XXH3 64-bit hash of a byte array with optional seed and range.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |