(bucket parent name)Returns a bucket from a Tx or Bucket.
Returns a bucket from a Tx or Bucket.
(bucket-delete b key)(bucket-get b key)(bucket-put b key val)(collect-page-ids b)(create-bucket parent name)Creates a bucket under a Tx or Bucket.
Creates a bucket under a Tx or Bucket.
(create-bucket-if-not-exists parent name)(delete-bucket parent name)(foreach parent f)Iterate over buckets in a Tx or key/value pairs in a Bucket.
Iterate over buckets in a Tx or key/value pairs in a Bucket.
(foreach-bucket parent f)Iterate over buckets in a Tx or Bucket, ignoring key/value entries.
Iterate over buckets in a Tx or Bucket, ignoring key/value entries.
(load-bucket tx root-pgid sequence inline-bytes)(move-bucket parent old-name new-name)Rename a bucket within a Tx or Bucket, or move a bucket to another parent bucket.
Rename a bucket within a Tx or Bucket, or move a bucket to another parent bucket.
(new-bucket tx)(next-sequence b)(rebalance-bucket-recursive b)(sequence b)(set-fill-percent! b v)(set-sequence! b v)(spill-bucket-recursive b)(spill-bucket-root b)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |