(bucket parent name)(check tx)(check tx opts)Return a seq of consistency check errors for a transaction.
Return a seq of consistency check errors for a transaction.
(close-db db)(compact dst-db src-db tx-max-size)Copy keys from src-db into dst-db with optional tx-max-size caps. Mirrors Go's bolt.Compact behavior.
Copy keys from src-db into dst-db with optional tx-max-size caps. Mirrors Go's bolt.Compact behavior.
(create-bucket parent name)(create-bucket-if-not-exists parent name)(cursor parent)(delete b key)(delete-bucket parent name)(entries c)(first c)(first-raw c)(foreach parent f)(foreach-bucket parent f)(get b key)(inspect parent)(keys c)(last c)(move-bucket parent old-name new-name)(next c)(next-raw c)(next-sequence b)(open-db path)(open-db path opts)(page-info tx pgid)Return page info for a pgid. Uses freelist membership to mark pages as free.
Return page info for a pgid. Uses freelist membership to mark pages as free.
(prev c)(put b key val)(seek c key)(seek-raw c key)(sequence b)(set-fill-percent b v)(set-sequence b v)(stats parent)(update db f)(update db f opts)(values c)(view db f)(with-tx-ro [sym db] & body)(with-tx-rw [sym db] & body)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |