(begin-tx db writable?)(check tx)(check tx {:keys [page-id kv-stringer] :or {page-id 0}})Run consistency checks for a transaction. Returns a seq of error strings.
Run consistency checks for a transaction. Returns a seq of error strings.
(commit tx)(commit tx {:keys [skip-sync?]})(page-info tx pgid)Return page info for a pgid, with type set to "free" when the pgid is in the freelist. Returns nil when pgid is beyond the high-water mark.
Return page info for a pgid, with type set to "free" when the pgid is in the freelist. Returns nil when pgid is beyond the high-water mark.
(rollback tx)(tx-allocate-page tx)(update db f)(update db f commit-opts)(view db f)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |