(close-db mdb)(create-db path)(create-db path opts)(create-target-state path)(create-target-state path opts)Returns :blank|:initialized or throws when the file has a partial or invalid MilaDB initialization.
Returns :blank|:initialized or throws when the file has a partial or invalid MilaDB initialization.
(db? v)(open-db path)(open-db path opts)(store? v)(view mdb f)(with-write-tx mdb f)(with-write-tx mdb f opts)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |