(get-provider)(read reader)(read opts reader)Read one EDN form from reader.
Delegates to clojure.edn/read.
Read one EDN form from `reader`. Delegates to `clojure.edn/read`.
(read-string s)(read-string opts s)Read EDN from s.
When fast-edn.core/read-string is present on the classpath, it will be used.
The fallback is clojure.edn/read-string.
Reader options are merged with classpath data readers before dispatch.
Read EDN from `s`. When `fast-edn.core/read-string` is present on the classpath, it will be used. The fallback is `clojure.edn/read-string`. Reader options are merged with classpath data readers before dispatch.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |