(entity view eid)Create a lazy entity view for eid.
Create a lazy entity view for eid.
(entity-db ent)(entity? v)(touch ent)Realize all attributes for an entity, including component entities recursively.
Realize all attributes for an entity, including component entities recursively.
(touch->map ent)Touch and return a realized entity map.
Touch and return a realized entity map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |