(aevt-key a-id e-bytes tx-id added? v)Build AEVT key bytes: (2, a, e, t*, retract?, v). retract? is (not added?) so additions sort before retractions for the same t*.
Build AEVT key bytes: (2, a, e, t*, retract?, v). retract? is (not added?) so additions sort before retractions for the same t*.
(aevt-prefix a-id e-bytes)Prefix bytes for (2, a, e).
Prefix bytes for (2, a, e).
(avet-key a-id v e-bytes tx-id)Build AVET key bytes: (3, a, v, e, t*).
Build AVET key bytes: (3, a, v, e, t*).
(avet-prefix a-id v)Prefix bytes for (3, a, v).
Prefix bytes for (3, a, v).
(eavt-key e-bytes a-id tx-id added? v)Build EAVT key bytes: (1, e, a, t*, retract?, v). retract? is (not added?) so additions sort before retractions for the same t*.
Build EAVT key bytes: (1, e, a, t*, retract?, v). retract? is (not added?) so additions sort before retractions for the same t*.
(eavt-prefix e-bytes a-id)Prefix bytes for (1, e, a).
Prefix bytes for (1, e, a).
(log-key tx-id e-bytes a-id v added?)Build LOG key bytes: (0, t*, e, a, v, added?).
Build LOG key bytes: (0, t*, e, a, v, added?).
(pack-prefix prefix)Pack a tuple or return bytes for an already-packed prefix.
Pack a tuple or return bytes for an already-packed prefix.
(prefix->range prefix)Return [start end-exclusive] bytes for a prefix tuple or byte-array.
Return [start end-exclusive] bytes for a prefix tuple or byte-array.
(prefix-end prefix)Return the exclusive upper bound for a byte prefix, or nil if unbounded.
Return the exclusive upper bound for a byte prefix, or nil if unbounded.
(t-asc t-desc)Decode descending tx-id back to ascending tx-id.
Decode descending tx-id back to ascending tx-id.
(t-desc tx-id)Encode tx-id in descending order (newer txs sort first).
Encode tx-id in descending order (newer txs sort first).
(vaet-key v a-id e-bytes tx-id)Build VAET key bytes: (4, v, a, e, t*).
Build VAET key bytes: (4, v, a, e, t*).
(vaet-prefix v a-id)Prefix bytes for (4, v, a).
Prefix bytes for (4, v, a).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |