(q query & args)Execute a basic Datalog query. Returns realized results by default.
Execute a basic Datalog query. Returns realized results by default.
(query-stats query & args)Execute a query and return results with operator stats from the execution plan.
Execute a query and return results with operator stats from the execution plan.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |