(bytes->hex val)Return a lowercase hex string for a byte array.
Return a lowercase hex string for a byte array.
(compare-items a b)Compare two tuple items using tuple ordering rules.
Compare two tuple items using tuple ordering rules.
(compare-tuples a b)Compare two tuples for ordering consistent with packed byte order.
Compare two tuples for ordering consistent with packed byte order.
(from-items items)Create a Tuple from a sequence of items.
Create a Tuple from a sequence of items.
(pack t)(pack t prefix)Pack a Tuple or list of items into a byte array.
Pack a Tuple or list of items into a byte array.
(pack-hex t)Pack a tuple and render the bytes as a lowercase hex string.
Pack a tuple and render the bytes as a lowercase hex string.
(pack-maybe-versionstamp t)Pack a Tuple, using versionstamp format if needed (internal helper).
Pack a Tuple, using versionstamp format if needed (internal helper).
(pack-with-versionstamp t)(pack-with-versionstamp t prefix)Pack a Tuple with exactly one incomplete Versionstamp, appending the version offset.
Pack a Tuple with exactly one incomplete Versionstamp, appending the version offset.
(tuple-items t)Return a copy of Tuple elements.
Return a copy of Tuple elements.
(tuple-packed-size t)(tuple-packed-size t nested?)Return the packed size of a Tuple.
Return the packed size of a Tuple.
(tuple? v)(unpack bytes)(unpack bytes offset length)Decode a byte array into a Tuple.
Decode a byte array into a Tuple.
(unpack-items src)(unpack-items src offset length)Decode tuple items from a byte array or other bytes-like input.
Decode tuple items from a byte array or other bytes-like input.
(versionstamp-complete tr-version)(versionstamp-complete tr-version user-version)(versionstamp-complete? v)(versionstamp-from-bytes version-bytes)(versionstamp-incomplete)(versionstamp-incomplete user-version)(versionstamp-user-version v)(versionstamp? v)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |